@@ -11,6 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+#  TODO:  add back in when artifactz is published to a repo
+# from artifactz.artifact_registry import ArtifactRegistry
+from providah.factories.package_factory import PackageFactory as pf
+
 from servz.core.build_step import BuildStep
 
 
@@ -20,6 +24,9 @@ class PackagePublisher(BuildStep):
         super().__init__()
         self._build_flows: list = list()
 
+        artifactz_config = kwargs['artifactz']
+        #  self.__artifact_registry: ArtifactRegistry = pf.create(key=artifactz_config['type'], configuration=artifactz_config['conf'])
+
     def build_part(self, **kwargs):
 
         raise NotImplementedError(f'Method not implemented for {type(self).__name__}.')
