@@ -13,6 +13,7 @@
 # limitations under the License.
 import platform
 import os
+from pathlib import Path
 
 
 class ProjectConfig:
@@ -31,13 +32,12 @@ class ProjectConfig:
 
     @classmethod
     def config_path(cls):
-        return os.path.join(cls.home(), "." + '/'.join(__name__.split('.')[:-1]) + "/configuration.yml")
+        return os.path.join(cls.home(), f'.{__name__.split(".")[0]}/configuration.yml')
 
     @classmethod
     def env_path(cls):
-        return os.path.join(cls.home(), "." + '/'.join(__name__.split('.')[:-1]) + "/command_config.yml")
+        return os.path.join(cls.home(), f'.{__name__.split(".")[0]}/command_config.yml')
 
     @classmethod
     def package_root(cls):
-
-        return "/".join(os.path.dirname(__file__).split("\\")[:-3])
+        return Path(__file__).parent.parent.parent
